==> escapework-manager-subscribers-0.5.0-211463.tar: src/EscapeWork/Manager/Subscribers/Controllers/SubscribersController.php <==
<?php namespace EscapeWork\Manager\Subscribers\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Subscribers\Repositories\SubscriberRepository;
use View;
use Input;
use Redirect;
use Response;
use Request;

class SubscribersController extends ManagerController
{

    public function __construct(SubscriberRepository $subscriber)
    {
        $this->subscriber = $subscriber;

        # filters
        $this->enableDefaultFilters('subscribers');
    }

    /**
     * Listando os banners
     */
    public function index()
    {
        $view              = View::make('manager-subscribers::subscribers.index');
        $view->subscribers = $this->subscriber->orderBy('created_at', 'desc')->paginate();

        return $view;
    }

    public function create()
    {
        $this->subscriber->fill(Input::old());

        $view             = View::make('manager-subscribers::subscribers.form');
        $view->subscriber = $this->subscriber;
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            if (Request::ajax()) {
                return Response::json(array(
                    'errors'     => Subscriber::$messages,
                    'subscriber' => $this->subscriber->toArray(),
                ));
            } else {
                return Redirect::route('manager.subscribers.create')
                        ->withInput()
                        ->with('errors', Subscriber::$messages);
            }
        }

        $this->subscriber->save();

        if (Request::ajax()) {
            return Response::json(array(
                'message'    => 'Cadastro realizado com sucesso',
                'subscriber' => $this->subscriber->toArray(),
            ));
        } else {
            return Redirect::route('manager.subscribers.index')
                    ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi inserido com sucesso!');
        }
    }

    public function edit($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->fill(Input::old());

        $view             = View::make('manager-subscribers::subscribers.form');
        $view->subscriber = $this->subscriber;
        $view->edit       = true;

        return $view;
    }

    public function update($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            return Redirect::route('manager.subscribers.create')
                    ->withInput()
                    ->with('errors', Subscriber::$messages);
        }

        $this->subscriber->save();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi atualizado com sucesso!');
    }

    public function destroy($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->delete();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi excluído com sucesso!');
    }

    public function export()
    {
        $subscribers = $this->subscriber->all();

        $content = null;
        $header  = null;

        foreach ($subscribers as $subscriber) {
            $subscriber = $subscriber->toArray();
            $total      = count($subscriber);

            if ($header == null) {
                $i = 1;
                foreach ($subscriber as $field => $value) {
                    $header .= $field . ';';
                    $header .= $i < $total ? null : "\n\r";

                    $i++;
                }
            }

            $i = 1;
            foreach ($subscriber as $field => $value) {
                $content .= $value . ';';
                $content .= $i < $total ? null : "\n\r";

                $i++;
            }
        }


        /**
         * Cabeçalhos
         */
        header('Content-Type: text/html; charset=utf-8');
        header('Content-type: application/octet-stream');
        header('Content-Disposition: attachment; filename=cadastros-site-'.date('Y-m-d').'.csv');
        header('Pragma: no-cache');
        header('Expires: 0');

        echo $header . $content;
    }

}

==> escapework-manager-subscribers-0.9.3-6582b7.tar: src/EscapeWork/Manager/Subscribers/Controllers/SubscribersController.php <==
<?php namespace EscapeWork\Manager\Subscribers\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Subscribers\Repositories\Subscriber\SubscriberRepository;
use EscapeWork\Manager\Services\Exporter\CSVExporter;
use View;
use Config;
use Input;
use Redirect;
use Response;
use Request;

class SubscribersController extends ManagerController
{

    public function __construct(SubscriberRepository $subscriber)
    {
        $this->subscriber = $subscriber;

        # filters
        $this->enableDefaultFilters('subscribers');
    }

    /**
     * Listando os banners
     */
    public function index()
    {
        $view              = View::make(Config::get('manager-subscribers::views.subscribers.index'));
        $view->subscribers = $this->subscriber->filterAndPaginate(Input::all());

        return $view;
    }

    public function create()
    {
        $this->subscriber->fill(Input::old());

        $view             = View::make(Config::get('manager-subscribers::views.subscribers.form'));
        $view->subscriber = $this->subscriber;
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            if (Request::ajax()) {
                return Response::json(array(
                    'errors'     => $this->subscriber->getValidationErrors()->toArray(),
                    'subscriber' => $this->subscriber->toArray(),
                ));
            } else {
                return Redirect::route('manager.subscribers.create')
                        ->withInput()
                        ->with('errors', $this->subscriber->getValidationErrors()->toArray());
            }
        }

        $this->subscriber->save();

        if (Request::ajax()) {
            return Response::json(array(
                'message'    => 'Cadastro realizado com sucesso',
                'subscriber' => $this->subscriber->toArray(),
            ));
        } else {
            return Redirect::route('manager.subscribers.index')
                    ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi inserido com sucesso!');
        }
    }

    public function edit($id)
    {
        $this->subscriber = $this->subscriber->findOrFail($id);
        $this->subscriber->fill(Input::old());

        $view             = View::make(Config::get('manager-subscribers::views.subscribers.form'));
        $view->subscriber = $this->subscriber;
        $view->edit       = true;

        return $view;
    }

    public function update($id)
    {
        $this->subscriber = $this->subscriber->findOrFail($id);
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            return Redirect::route('manager.subscribers.create')
                    ->withInput()
                    ->with('errors', $this->subscriber->getValidationErrors()->toArray());
        }

        $this->subscriber->save();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi atualizado com sucesso!');
    }

    public function destroy($id)
    {
        $this->subscriber = $this->subscriber->findOrFail($id);
        $this->subscriber->delete();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi excluído com sucesso!');
    }

    /**
     * Exportando os contatos para CSV
     */
    public function export()
    {
        $subscribers = $this->subscriber->all();
        $exporter    = new CSVExporter();

        # header
        $exporter->writeLine(array(
            'ID', 'Nome', 'E-mail', 'Sexo', 'Data de Nascimento', 'Cidade', 'Estado', 'País', 'Data de cadastro', 'Data de atualização',
        ));

        foreach ($subscribers as $subscriber) {
            $exporter->writeLine($subscriber->toArray());
        }

        return $exporter->export(array('filename' => 'contatos-newsletter-'.date('Y-m-d')));
    }
}
